@@ -5,5 +5,7 @@ population = [
     {'Alias': 'Palatino', 'Name': 'Palatino Sans Informal LT Pro'},
     {'Alias': 'Gill Sans', 'Name': 'Gill Sans'},
     {'Alias': 'Helvetica', 'Name': 'Helvetica'},
-    {'Alias': 'Verdana', 'Name': 'Verdana'}
+    {'Alias': 'Verdana', 'Name': 'Verdana'},
+    {'Alias': 'Eurostile', 'Name': 'Eurostile BoldExtendedTwo'},
+    {'Alias': 'Courier', 'Name': 'Courier'},
 ]
\ No newline at end of file
