@@ -2,7 +2,17 @@
 gen_example_diagrams.py – Here we generate all or some of the examples
 """
 from flatland.xuml.xuml_classdiagram import XumlClassDiagram
+from flatland import version
 from pathlib import Path
+import logging
+import logging.config
+from datetime import datetime
+
+def get_logger():
+    """Initiate the logger"""
+    log_conf_path = Path(__file__).parent.parent / 'log.conf'  # Logging configuration is in this file
+    logging.config.fileConfig(fname=log_conf_path, disable_existing_loggers=False)
+    return logging.getLogger(__name__)  # Create a logger for this module
 
 # Here we map the test code to a tuple defining the model and layout file
 # combination to test
@@ -14,6 +24,7 @@ tests = {
     't004': ('tall_class', 't004_single_cell_node_tall'),
     't005': ('aircraft2', 't005_bending_binary_one'),
     't006': ('aircraft2', 't006_reverse_straight_binary_horiz'),
+    't007': ('aircraft2', 't007_straight_binary_horiz_offset'),
     't010': ('fat_class', 't010_spanning_node_ll_corner'),
     't011': ('tall_class', 't011_spanning_node_middle_tall'),
     't012': ('fat_class', 't012_spanning_node_middle_wide'),
@@ -24,6 +35,7 @@ tests = {
     't022': ('aircraft2', 't022_bending_binary_horizontal_d1'),
     't023': ('aircraft2', 't023_bending_binary_twice'),
     't025': ('waypoint', 't025_reflexive_upper_right'),
+    't026': ('aircraft2', 't026_single_bend_binary'),
     't030': ('aircraft3', 't030_straight_binary_tertiary'),
     't031': ('aircraft3', 't031_straight_binary_tertiary_horizontal'),
     't032': ('aircraft3', 't032_1bend_tertiary_left'),
@@ -34,6 +46,8 @@ tests = {
     # Tree connectors (generalization)
     't040': ('aircraft_tree1', 't040_ibranch_horiz'),
     't041': ('aircraft_tree1', 't041_ibranch_vert'),
+    't042': ('aircraft_tree1', 't042_ibranch_horiz_span'),
+    't043': ('aircraft_tree_wrap', 't043_ibranch_wrap'),
     't050': ('aircraft_tree1', 't050_rbranch_horiz'),
     't051': ('aircraft_tree1', 't051_rbranch_vert'),
     't052': ('aircraft_tree2', 't052_rbranch_vert_corner'),
@@ -44,9 +58,13 @@ tests = {
     't100': ('flatland_node_subsystem', 't100_flatland_node_subsystem'),
 }
 
+logger = get_logger()
+logger.info(f'Flatland testing log: {datetime.now().strftime("%Y-%m-%d %H:%M:%S")}')
+logger.info(f'Flatland version: {version}')
+
 exdir = Path(__file__).parent.parent / "examples"
 
-selected_tests = ['t006']  # Selected tests to run, if any
+selected_tests = ['t025']  # Selected tests to run, if any
 #selected_tests = ['t010', 't011', 't012', 't013']  # Selected tests to run, if any
 # If no tests are selected, all of them will be run
 run_tests = selected_tests if selected_tests else list(tests.keys())
@@ -64,5 +82,7 @@ for selected_test in run_tests:
     cd = XumlClassDiagram(
         xuml_model_path=model_file_path,
         flatland_layout_path=layout_file_path,
-        diagram_file_path=diagram_file_path
+        diagram_file_path=diagram_file_path,
+        rebuild=False,
+        show_grid=False
     )
\ No newline at end of file
